@@ -1,3 +1,4 @@
+"""The powermeter device class."""
 # -*- coding: utf-8 -*-
 
 import logging
@@ -14,6 +15,7 @@ class FritzhomeDevicePowermeter(FritzhomeDeviceBase):
     power = None
     energy = None
     voltage = None
+    current = None
 
     def _update_from_node(self, node):
         super()._update_from_node(node)
@@ -38,8 +40,17 @@ class FritzhomeDevicePowermeter(FritzhomeDeviceBase):
         except Exception:
             pass
 
+        if (
+            isinstance(self.power, int)
+            and isinstance(self.voltage, int)
+            and self.voltage > 0
+        ):
+            self.current = self.power / self.voltage * 1000
+        else:
+            self.current = None
+
     def get_switch_power(self):
-        """The switch state."""
+        """Get the switch state."""
         return self._fritz.get_switch_power(self.ain)
 
     def get_switch_energy(self):
